@@ -1,11 +1,13 @@
 #!/usr/bin/env python
 
+import test
 from tkinter import W
-from actions import get
 
 import rich_click as click
 from click_shell import shell
 
+import get
+
 click.rich_click.OPTION_GROUPS = {
     "mytool": [
         {
@@ -31,15 +33,21 @@ def print_version(ctx, param, value):
 
 @shell(prompt="ff > ", intro="Starting ff...")
 @click.option(
-    "--version", is_flag=True, callback=print_version, expose_value=False, is_eager=True
+    "--version",
+    is_flag=True,
+    callback=print_version,
+    expose_value=False,
+    is_eager=True,
 )
 @click.pass_context
 def cli(ctx):
 
-    #TODO: Pass something if needed in near future
+    # TODO: Pass something if needed in near future
     ctx.obj = {}
 
+
 cli.add_command(get.get)
+cli.add_command(test.test)
 
 if __name__ == "__main__":
 
