@@ -25,17 +25,14 @@ def news(ctx, log_level):
 
     logging.basicConfig(level=log_level.upper())
 
-    from utils import Utils
     from news import News
 
     news = News()
-    utils = Utils()
 
     news_category_list = news.get_news_categories()
     logging.debug("News category list: %s", news_category_list)
     articles_list = news.get_news_by_categories(news_category_list['category'])
     print_list = []
-    print_header = ['Title', 'URL']
     menu_list = []
     menu_dict = {}
     for article in articles_list:
